pm4py.algo.discovery.correlation\_mining.variants package
=========================================================

Submodules
----------

pm4py.algo.discovery.correlation\_mining.variants.classic module
----------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.correlation_mining.variants.classic
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.correlation\_mining.variants.classic\_split module
-----------------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.correlation_mining.variants.classic_split
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.correlation\_mining.variants.trace\_based module
---------------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.correlation_mining.variants.trace_based
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.correlation_mining.variants
   :members:
   :undoc-members:
   :show-inheritance:
